@@ -263,6 +263,39 @@ SYZ_CAPI syz_ErrorCode syz_createNoiseGenerator(syz_Handle *out, syz_Handle cont
                                                 void *config, void *userdata,
                                                 syz_UserdataFreeCallback *userdata_free_callback);
 
+struct syz_SineBankWave {
+  double frequency_mul;
+  double phase;
+  double gain;
+};
+
+struct syz_SineBankConfig {
+  const struct syz_SineBankWave *waves;
+  unsigned long long wave_count;
+  double initial_frequency;
+};
+
+SYZ_CAPI void syz_initSineBankConfig(struct syz_SineBankConfig *cfg);
+
+SYZ_CAPI syz_ErrorCode syz_createFastSineBankGenerator(syz_Handle *out, syz_Handle context,
+                                                       const struct syz_SineBankConfig *bank_config, void *config,
+                                                       void *userdata,
+                                                       syz_UserdataFreeCallback *userdata_free_callback);
+SYZ_CAPI syz_ErrorCode syz_createFastSineBankGeneratorSine(syz_Handle *out, syz_Handle context,
+                                                           double initial_frequency, void *config, void *userdata,
+                                                           syz_UserdataFreeCallback *userdata_free_callback);
+SYZ_CAPI syz_ErrorCode syz_createFastSineBankGeneratorTriangle(syz_Handle *out, syz_Handle context,
+                                                               double initial_frequency, unsigned int partials,
+                                                               void *config, void *userdata,
+                                                               syz_UserdataFreeCallback *userdata_free_callback);
+SYZ_CAPI syz_ErrorCode syz_createFastSineBankGeneratorSquare(syz_Handle *out, syz_Handle context,
+                                                             double initial_frequency, unsigned int partials,
+                                                             void *config, void *userdata,
+                                                             syz_UserdataFreeCallback *userdata_free_callback);
+SYZ_CAPI syz_ErrorCode syz_createFastSineBankGeneratorSaw(syz_Handle *out, syz_Handle context, double initial_frequency,
+                                                          unsigned int partials, void *config, void *userdata,
+                                                          syz_UserdataFreeCallback *userdata_free_callback);
+
 struct syz_RouteConfig {
   double gain;
   double fade_time;
