@@ -18,6 +18,7 @@ enum SYZ_OBJECT_TYPE {
   SYZ_OTYPE_GLOBAL_FDN_REVERB,
   SYZ_OTYPE_STREAM_HANDLE,
   SYZ_OTYPE_AUTOMATION_BATCH,
+  SYZ_OTYPE_FAST_SINE_BANK_GENERATOR,
 };
 
 enum SYZ_PANNER_STRATEGY {
@@ -96,6 +97,8 @@ enum SYZ_PROPERTIES {
 
   SYZ_P_CURRENT_TIME,
   SYZ_P_SUGGESTED_AUTOMATION_TIME,
+
+  SYZ_P_FREQUENCY,
 };
 
 enum SYZ_EVENT_TYPES {
